@@ -37,18 +37,47 @@ def get_formatted_tag(version):
     return tag_format.format(version=version)
 
 
-def get_commit_log(from_rev=None):
+def get_formatted_commit(version: str) -> str:
+    commit_subject = config.get("commit_subject")
+    message = commit_subject.format(version=version)
+
+    # Add an extended message if one is configured
+    commit_message = config.get("commit_message")
+    if commit_message:
+        message += "\n\n"
+        message += commit_message.format(version=version)
+
+    return message
+
+
+def get_commit_log(from_rev=None, to_rev=None):
     """Yield all commit messages from last to first."""
-    rev = None
     if from_rev:
         from_rev = get_formatted_tag(from_rev)
         try:
             repo().commit(from_rev)
-            rev = f"...{from_rev}"
         except BadName:
             logger.debug(
                 f"Reference {from_rev} does not exist, considering entire history"
             )
+            from_rev = None
+    if to_rev:
+        to_rev = get_formatted_tag(to_rev)
+        try:
+            repo().commit(to_rev)
+        except BadName:
+            logger.debug(
+                f"Reference {to_rev} does not exist, considering entire history until HEAD"
+            )
+            to_rev = None
+
+    rev = None
+    if from_rev and to_rev:
+        rev = f"{to_rev}...{from_rev}"
+    elif from_rev:
+        rev = f"...{from_rev}"
+    elif to_rev:
+        rev = f"{to_rev}..."
 
     for commit in repo().iter_commits(rev):
         yield (commit.hexsha, commit.message.replace("\r\n", "\n"))
@@ -126,15 +155,7 @@ def commit_new_version(version: str):
     """
     from .history import load_version_declarations
 
-    commit_subject = config.get("commit_subject")
-    message = commit_subject.format(version=version)
-
-    # Add an extended message if one is configured
-    commit_message = config.get("commit_message")
-    if commit_message:
-        message += "\n\n"
-        message += commit_message.format(version=version)
-
+    commit_message = get_formatted_commit(version)
     commit_author = config.get(
         "commit_author",
         "semantic-release <semantic-release>",
@@ -144,7 +165,7 @@ def commit_new_version(version: str):
         git_path: PurePath = PurePath(os.getcwd(), declaration.path).relative_to(repo().working_dir)  # type: ignore
         repo().git.add(str(git_path))
 
-    return repo().git.commit(m=message, author=commit_author)
+    return repo().git.commit(m=commit_message, author=commit_author)
 
 
 @LoggedFunction(logger)
