@@ -12,7 +12,14 @@ def reset_config():
     """
     yield
     from importlib import reload
+
     reload(semantic_release.settings)
     reload(semantic_release.vcs_helpers)
     reload(semantic_release.history)
     reload(semantic_release.history.logs)
+
+
+def wrapped_config_get(**kwargs):
+    from semantic_release.settings import config
+
+    return lambda *args: {**config, **kwargs}.get(*args)
