@@ -10,7 +10,11 @@ from semantic_release.history import (
     PatternVersionDeclaration,
     TomlVersionDeclaration,
     VersionDeclaration,
+    get_current_release_version,
+    get_current_release_version_by_commits,
+    get_current_release_version_by_tag,
     get_current_version,
+    get_current_version_by_config_file,
     get_current_version_by_tag,
     get_new_version,
     get_previous_version,
@@ -37,11 +41,20 @@ def test_current_version_should_return_correct_version():
     assert get_current_version() == semantic_release.__version__
 
 
+def test_current_release_version_should_return_correct_version():
+    assert get_current_release_version() == semantic_release.__version__
+
+
 @mock.patch("semantic_release.history.get_last_version", return_value="last_version")
 def test_current_version_should_return_git_version(mock_last_version):
     assert "last_version" == get_current_version_by_tag()
 
 
+@mock.patch("semantic_release.history.get_last_version", return_value="last_version")
+def test_current_release_version_should_return_git_version(mock_last_version):
+    assert "last_version" == get_current_release_version_by_tag()
+
+
 @mock.patch(
     "semantic_release.history.config.get", wrapped_config_get(version_source="tag")
 )
@@ -50,6 +63,34 @@ def test_current_version_should_return_default_version(mock_last_version):
     assert "0.0.0" == get_current_version()
 
 
+@mock.patch(
+    "semantic_release.history.config.get", wrapped_config_get(version_source="tag_only")
+)
+def test_current_version_should_run_with_tag_only(mocker):
+    mock_get_current_version_by_tag = mocker.patch(
+        "semantic_release.history.get_current_version_by_tag", return_value=None
+    )
+    mock_get_current_version_by_config_file = mocker.patch(
+        "semantic_release.history.get_current_version_by_config_file", return_value=None
+    )
+
+    get_current_version()
+
+    assert mock_get_current_version_by_tag.called
+    assert not mock_get_current_version_by_config_file.called
+
+
+@mock.patch("semantic_release.history.get_last_version", return_value=None)
+@mock.patch(
+    "semantic_release.history.get_current_release_version_by_commits",
+    return_value="0.0.0",
+)
+def test_current_release_version_should_return_default_version(
+    mock_last_version, mock_current_release_version_by_commits
+):
+    assert "0.0.0" == get_current_release_version()
+
+
 class TestGetPreviousVersion:
     @mock.patch(
         "semantic_release.history.get_commit_log",
@@ -60,33 +101,152 @@ class TestGetPreviousVersion:
 
     @mock.patch(
         "semantic_release.history.get_commit_log",
-        lambda: [("211", "0.10.0"), ("13", "0.9.0")],
+        lambda: [("211", "v0.10.0"), ("13", "v0.9.0")],
     )
     def test_should_return_correct_version_with_v(self):
         assert get_previous_version("0.10.0") == "0.9.0"
 
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [("211", "0.10.0-beta"), ("13", "0.9.0")],
+    )
+    def test_should_return_correct_version_from_prerelease(self):
+        assert get_previous_version("0.10.0-beta") == "0.9.0"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [("211", "0.10.0"), ("13", "0.10.0-beta"), ("13", "0.9.0")],
+    )
+    def test_should_return_correct_version_skip_prerelease(self):
+        assert get_previous_version("0.10.0-beta") == "0.9.0"
+
+
+class TestGetCurrentReleaseVersionByCommits:
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [("211", "0.10.0-beta.1"), ("13", "0.9.1-beta.1"), ("13", "0.9.0")],
+    )
+    def test_should_return_correct_version(self):
+        assert get_current_release_version_by_commits() == "0.9.0"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [("211", "v0.10.0-beta.1"), ("13", "0.9.1-beta.1"), ("13", "v0.9.0")],
+    )
+    def test_should_return_correct_version_with_v(self):
+        assert get_current_release_version_by_commits() == "0.9.0"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [("211", "0.10.0-beta.0"), ("13", "0.9.0")],
+    )
+    def test_should_return_correct_version_from_prerelease(self):
+        assert get_current_release_version_by_commits() == "0.9.0"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [
+            ("211", "0.0.24-beta.10"),
+            ("13", "0.0.23"),
+            ("14", "0.0.21-beta.0"),
+            ("15", "0.0.19"),
+        ],
+    )
+    def test_should_return_correct_version_from_large_prerelease(self):
+        assert get_current_release_version_by_commits() == "0.0.23"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [("211", "7.28.0"), ("13", "7.27.0")],
+    )
+    def test_should_return_correct_version_without_prerelease(self):
+        assert get_current_release_version_by_commits() == "7.28.0"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [
+            ("222", "chore(deps): bump random lib to 7.29.0"),
+            ("211", "7.28.0"),
+            ("13", "7.27.0"),
+        ],
+    )
+    def test_should_return_correct_version_ignoring_dependency_bumps(self):
+        assert get_current_release_version_by_commits() == "7.28.0"
+
+    @mock.patch(
+        "semantic_release.history.get_commit_log",
+        lambda: [
+            ("222", "7.29.0"),
+            ("211", "chore(release): 7.28.0"),
+            ("13", "7.27.0"),
+        ],
+    )
+    def test_should_return_correct_version_with_commit_subject(self):
+        with mock.patch(
+            "semantic_release.history.config.get",
+            wrapped_config_get(commit_subject="chore(release): {version}"),
+        ):
+            assert get_current_release_version_by_commits() == "7.28.0"
+
 
 class TestGetNewVersion:
     def test_major_bump(self):
-        assert get_new_version("0.0.0", "major") == "1.0.0"
-        assert get_new_version("0.1.0", "major") == "1.0.0"
-        assert get_new_version("0.1.9", "major") == "1.0.0"
-        assert get_new_version("10.1.0", "major") == "11.0.0"
+        assert get_new_version("0.0.0", "0.0.0", "major") == "1.0.0"
+        assert get_new_version("0.1.0", "0.1.0", "major") == "1.0.0"
+        assert get_new_version("0.1.9", "0.1.9", "major") == "1.0.0"
+        assert get_new_version("10.1.0", "10.1.0", "major") == "11.0.0"
 
     def test_minor_bump(self):
-        assert type(get_new_version("0.0.0", "minor")) is str
-        assert get_new_version("0.0.0", "minor") == "0.1.0"
-        assert get_new_version("1.2.0", "minor") == "1.3.0"
-        assert get_new_version("1.2.1", "minor") == "1.3.0"
-        assert get_new_version("10.1.0", "minor") == "10.2.0"
+        assert type(get_new_version("0.0.0", "0.0.0", "minor")) is str
+        assert get_new_version("0.0.0", "0.0.0", "minor") == "0.1.0"
+        assert get_new_version("1.2.0", "1.2.0", "minor") == "1.3.0"
+        assert get_new_version("1.2.1", "1.2.1", "minor") == "1.3.0"
+        assert get_new_version("10.1.0", "10.1.0", "minor") == "10.2.0"
 
     def test_patch_bump(self):
-        assert get_new_version("0.0.0", "patch") == "0.0.1"
-        assert get_new_version("0.1.0", "patch") == "0.1.1"
-        assert get_new_version("10.0.9", "patch") == "10.0.10"
+        assert get_new_version("0.0.0", "0.0.0", "patch") == "0.0.1"
+        assert get_new_version("0.1.0", "0.1.0", "patch") == "0.1.1"
+        assert get_new_version("10.0.9", "10.0.9", "patch") == "10.0.10"
 
     def test_none_bump(self):
-        assert get_new_version("1.0.0", None) == "1.0.0"
+        assert get_new_version("1.0.0", "1.0.0", None) == "1.0.0"
+
+    def test_prerelease(self):
+        assert get_new_version("1.0.1-beta.1", "1.0.0", None, True) == "1.0.1-beta.2"
+        assert get_new_version("1.0.1-beta.1", "1.0.0", "major", True) == "2.0.0-beta.1"
+        assert get_new_version("1.0.1-beta.1", "1.0.0", "minor", True) == "1.1.0-beta.1"
+        assert get_new_version("1.0.1-beta.1", "1.0.0", "patch", True) == "1.0.1-beta.2"
+        assert (
+            get_new_version("1.0.1-beta.1", "1.0.0", "patch", True, False)
+            == "1.0.1-beta.2"
+        )
+        assert (
+            get_new_version("1.0.1-beta.1", "1.0.0", None, True, False)
+            == "1.0.1-beta.1"
+        )
+
+        assert get_new_version("1.0.0", "1.0.0", None, True) == "1.0.1-beta.1"
+        assert get_new_version("1.0.0", "1.0.0", "major", True) == "2.0.0-beta.1"
+        assert get_new_version("1.0.0", "1.0.0", "minor", True) == "1.1.0-beta.1"
+        assert get_new_version("1.0.0", "1.0.0", "patch", True) == "1.0.1-beta.1"
+        assert get_new_version("1.0.0", "1.0.0", "patch", True, False) == "1.0.1-beta.1"
+        assert get_new_version("1.0.0", "1.0.0", None, True, False) == "1.0.0"
+
+        assert get_new_version("0.9.0-beta.1", "1.0.0", None, True) == "1.0.1-beta.1"
+        assert get_new_version("0.9.0-beta.1", "1.0.0", "major", True) == "2.0.0-beta.1"
+        assert get_new_version("0.9.0-beta.1", "1.0.0", "minor", True) == "1.1.0-beta.1"
+        assert get_new_version("0.9.0-beta.1", "1.0.0", "patch", True) == "1.0.1-beta.1"
+        assert (
+            get_new_version("0.9.0-beta.1", "1.0.0", "patch", True, False)
+            == "1.0.1-beta.1"
+        )
+        assert get_new_version("0.9.0-beta.1", "1.0.0", None, True, False) == "1.0.0"
+
+        with pytest.raises(ValueError):
+            get_new_version("0.9.0", "1.0.0", None, True)
+
+        with pytest.raises(ValueError):
+            get_new_version("1.0.0", "0.9.0", None, True)
 
 
 @mock.patch(
@@ -109,7 +269,7 @@ class TestVersionPattern:
             (
                 "path:__version__",
                 Path("path"),
-                r'__version__ *[:=] *["\'](\d+\.\d+(?:\.\d+)?)["\']',
+                r'__version__ *[:=] *["\'](\d+\.\d+\.\d+(-beta\.\d+)?)["\']',
             ),
         ],
     )
@@ -122,7 +282,11 @@ class TestVersionPattern:
         "str, path, pattern",
         [
             ("path:pattern", Path("path"), r"pattern"),
-            ("path:Version: {version}", Path("path"), r"Version: (\d+\.\d+(?:\.\d+)?)"),
+            (
+                "path:Version: {version}",
+                Path("path"),
+                r"Version: (\d+\.\d+\.\d+(-beta\.\d+)?)",
+            ),
         ],
     )
     def test_from_pattern(self, str, path, pattern):
@@ -253,11 +417,11 @@ class TestVersionPattern:
                     name = "my-package"
                     version = "0.1.0"
                     description = "A super package"
-                    
+
                     [build-system]
                     requires = ["poetry-core>=1.0.0"]
                     build-backend = "poetry.core.masonry.api"
-                    
+
                     [tool.semantic_release]
                     version_toml = "pyproject.toml:tool.poetry.version"
                     """
@@ -268,11 +432,11 @@ class TestVersionPattern:
                     name = "my-package"
                     version = "-"
                     description = "A super package"
-                    
+
                     [build-system]
                     requires = ["poetry-core>=1.0.0"]
                     build-backend = "poetry.core.masonry.api"
-                    
+
                     [tool.semantic_release]
                     version_toml = "pyproject.toml:tool.poetry.version"
                     """
@@ -309,7 +473,10 @@ class TestVersionPattern:
                         version_variable = "path:__version__"
                         """,
             patterns=[
-                (Path("path"), r'__version__ *[:=] *["\'](\d+\.\d+(?:\.\d+)?)["\']'),
+                (
+                    Path("path"),
+                    r'__version__ *[:=] *["\'](\d+\.\d+\.\d+(-beta\.\d+)?)["\']',
+                ),
             ],
         ),
         dict(
@@ -318,8 +485,8 @@ class TestVersionPattern:
                         version_variable = "path1:var1,path2:var2"
                         """,
             patterns=[
-                (Path("path1"), r'var1 *[:=] *["\'](\d+\.\d+(?:\.\d+)?)["\']'),
-                (Path("path2"), r'var2 *[:=] *["\'](\d+\.\d+(?:\.\d+)?)["\']'),
+                (Path("path1"), r'var1 *[:=] *["\'](\d+\.\d+\.\d+(-beta\.\d+)?)["\']'),
+                (Path("path2"), r'var2 *[:=] *["\'](\d+\.\d+\.\d+(-beta\.\d+)?)["\']'),
             ],
         ),
         dict(
@@ -331,8 +498,21 @@ class TestVersionPattern:
                         ]
                         """,
             patterns=[
-                (Path("path1"), r'var1 *[:=] *["\'](\d+\.\d+(?:\.\d+)?)["\']'),
-                (Path("path2"), r'var2 *[:=] *["\'](\d+\.\d+(?:\.\d+)?)["\']'),
+                (Path("path1"), r'var1 *[:=] *["\'](\d+\.\d+\.\d+(-beta\.\d+)?)["\']'),
+                (Path("path2"), r'var2 *[:=] *["\'](\d+\.\d+\.\d+(-beta\.\d+)?)["\']'),
+            ],
+        ),
+        dict(
+            pyproject="""\
+                        [tool.semantic_release]
+                        version_variable = "path:__version__"
+                        prerelease_tag = "alpha"
+                        """,
+            patterns=[
+                (
+                    Path("path"),
+                    r'__version__ *[:=] *["\'](\d+\.\d+\.\d+(-alpha\.\d+)?)["\']',
+                ),
             ],
         ),
         dict(
