@@ -2,6 +2,7 @@ from click.testing import CliRunner
 
 from semantic_release.cli import changelog, main, print_version, publish, version
 from semantic_release.errors import GitError, ImproperConfigurationError
+from semantic_release.repository import ArtifactRepo
 
 from . import mock, pytest, reset_config, wrapped_config_get
 from .mocks import mock_version_file
@@ -21,6 +22,8 @@ def test_main_should_call_correct_function(mocker, runner):
         noop=False,
         post=False,
         force_level=None,
+        prerelease=False,
+        prerelease_patch=True,
         retry=False,
         define=(),
     )
@@ -46,12 +49,16 @@ def test_version_by_commit_should_call_correct_functions(mocker):
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
 
     version()
 
-    mock_current_version.assert_called_once_with()
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", None)
-    mock_new_version.assert_called_once_with("1.2.3", "major")
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", "major", False, True)
     mock_set_new_version.assert_called_once_with("2.0.0")
     mock_commit_new_version.assert_called_once_with("2.0.0")
     mock_tag_new_version.assert_called_once_with("2.0.0")
@@ -81,25 +88,65 @@ def test_version_by_tag_with_commit_version_number_should_call_correct_functions
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+
+    version()
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", None)
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", "major", False, True)
+    mock_set_new_version.assert_called_once_with("2.0.0")
+    mock_commit_new_version.assert_called_once_with("2.0.0")
+    mock_tag_new_version.assert_called_once_with("2.0.0")
+
+
+def test_version_by_tag_only_with_commit_version_number_should_call_correct_functions(
+    mocker,
+):
+
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(
+            version_source="tag_only",
+            commit_version_number=True,
+        ),
+    )
+
+    mock_set_new_version = mocker.patch("semantic_release.cli.set_new_version")
+    mock_tag_new_version = mocker.patch("semantic_release.cli.tag_new_version")
+    mock_commit_new_version = mocker.patch("semantic_release.cli.commit_new_version")
+    mock_new_version = mocker.patch(
+        "semantic_release.cli.get_new_version", return_value="2.0.0"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value="major"
+    )
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
 
     version()
 
     mock_current_version.assert_called_once_with()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", None)
-    mock_new_version.assert_called_once_with("1.2.3", "major")
-    mock_set_new_version.assert_called_once_with("2.0.0")
-    mock_commit_new_version.assert_called_once_with("2.0.0")
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", "major", False, True)
+    assert not mock_set_new_version.called
+    assert not mock_commit_new_version.called
     mock_tag_new_version.assert_called_once_with("2.0.0")
 
 
 def test_version_by_tag_should_call_correct_functions(mocker):
     mocker.patch(
         "semantic_release.cli.config.get",
-        wrapped_config_get(
-            version_source="tag",
-        ),
+        wrapped_config_get(version_source="tag"),
     )
-    mocker.patch("semantic_release.cli.config.get", lambda *x, **y: False)
     mock_set_new_version = mocker.patch("semantic_release.cli.set_new_version")
     mock_tag_new_version = mocker.patch("semantic_release.cli.tag_new_version")
     mock_new_version = mocker.patch(
@@ -111,16 +158,82 @@ def test_version_by_tag_should_call_correct_functions(mocker):
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+
+    version()
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", None)
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", "major", False, True)
+    mock_set_new_version.assert_called_once_with("2.0.0")
+    mock_tag_new_version.assert_called_once_with("2.0.0")
+
+
+def test_version_by_tag_only_should_call_correct_functions(mocker):
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(version_source="tag_only"),
+    )
+    mock_set_new_version = mocker.patch("semantic_release.cli.set_new_version")
+    mock_tag_new_version = mocker.patch("semantic_release.cli.tag_new_version")
+    mock_new_version = mocker.patch(
+        "semantic_release.cli.get_new_version", return_value="2.0.0"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value="major"
+    )
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
 
     version()
 
     mock_current_version.assert_called_once_with()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", None)
-    mock_new_version.assert_called_once_with("1.2.3", "major")
-    mock_set_new_version.assert_called_once_with("2.0.0")
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", "major", False, True)
+    assert not mock_set_new_version.called
     mock_tag_new_version.assert_called_once_with("2.0.0")
 
 
+def test_version_by_commit_without_tag_should_call_correct_functions(mocker):
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(version_source="commit", tag_commit=False),
+    )
+    mock_set_new_version = mocker.patch("semantic_release.cli.set_new_version")
+    mock_tag_new_version = mocker.patch("semantic_release.cli.tag_new_version")
+    mock_commit_new_version = mocker.patch("semantic_release.cli.commit_new_version")
+    mock_new_version = mocker.patch(
+        "semantic_release.cli.get_new_version", return_value="2.0.0"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value="major"
+    )
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+
+    version()
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", None)
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", "major", False, True)
+    mock_set_new_version.assert_called_once_with("2.0.0")
+    mock_commit_new_version.assert_called_once_with("2.0.0")
+    assert not mock_tag_new_version.called
+
+
 def test_force_major(mocker, runner):
     mock_version = mocker.patch("semantic_release.cli.version")
     result = runner.invoke(main, ["version", "--major"])
@@ -128,6 +241,8 @@ def test_force_major(mocker, runner):
         noop=False,
         post=False,
         force_level="major",
+        prerelease=False,
+        prerelease_patch=True,
         retry=False,
         define=(),
     )
@@ -142,6 +257,8 @@ def test_force_minor(mocker, runner):
         noop=False,
         post=False,
         force_level="minor",
+        prerelease=False,
+        prerelease_patch=True,
         retry=False,
         define=(),
     )
@@ -156,6 +273,8 @@ def test_force_patch(mocker, runner):
         noop=False,
         post=False,
         force_level="patch",
+        prerelease=False,
+        prerelease_patch=True,
         retry=False,
         define=(),
     )
@@ -170,12 +289,29 @@ def test_retry(mocker, runner):
         noop=False,
         post=False,
         force_level=None,
+        prerelease=False,
+        prerelease_patch=True,
         retry=True,
         define=(),
     )
     assert result.exit_code == 0
 
 
+def test_prerelease_patch(mocker, runner):
+    mock_version = mocker.patch("semantic_release.cli.version")
+    result = runner.invoke(main, ["version", "--no-prerelease-patch"])
+    mock_version.assert_called_once_with(
+        noop=False,
+        post=False,
+        force_level=None,
+        prerelease=False,
+        prerelease_patch=False,
+        retry=False,
+        define=(),
+    )
+    assert result.exit_code == 0
+
+
 def test_noop_mode(mocker):
     mock_tag_new_version = mocker.patch("semantic_release.cli.tag_new_version")
     mock_set_new = mocker.patch("semantic_release.cli.commit_new_version")
@@ -195,6 +331,8 @@ def test_cli_print_version(mocker, runner):
     mock_print_version.assert_called_once_with(
         current=False,
         force_level=None,
+        prerelease=False,
+        prerelease_patch=True,
         noop=False,
         post=False,
         retry=False,
@@ -209,6 +347,24 @@ def test_cli_print_version_force_major(mocker, runner):
     mock_print_version.assert_called_once_with(
         current=False,
         force_level="major",
+        prerelease=False,
+        prerelease_patch=True,
+        noop=False,
+        post=False,
+        retry=False,
+        define=(),
+    )
+    assert result.exit_code == 0
+
+
+def test_cli_print_version_prerelease(mocker, runner):
+    mock_print_version = mocker.patch("semantic_release.cli.print_version")
+    result = runner.invoke(main, ["print-version", "--prerelease"])
+    mock_print_version.assert_called_once_with(
+        current=False,
+        force_level=None,
+        prerelease=True,
+        prerelease_patch=True,
         noop=False,
         post=False,
         retry=False,
@@ -223,6 +379,8 @@ def test_cli_print_version_current(mocker, runner):
     mock_print_version.assert_called_once_with(
         current=True,
         force_level=None,
+        prerelease=False,
+        prerelease_patch=True,
         noop=False,
         post=False,
         retry=False,
@@ -237,6 +395,8 @@ def test_cli_print_version_next(mocker, runner):
     mock_print_version.assert_called_once_with(
         current=False,
         force_level=None,
+        prerelease=False,
+        prerelease_patch=True,
         noop=False,
         post=False,
         retry=False,
@@ -255,21 +415,28 @@ def test_print_version_no_change(mocker, runner, capsys):
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
 
     print_version()
     outerr = capsys.readouterr()
     assert outerr.out == ""
     assert outerr.err == "No release will be made.\n"
 
-    mock_current_version.assert_called_once_with()
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", None)
-    mock_new_version.assert_called_once_with("1.2.3", None)
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", None, False, True)
 
 
 def test_print_version_change(mocker, runner, capsys):
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
     mock_evaluate_bump = mocker.patch(
         "semantic_release.cli.evaluate_version_bump", return_value="minor"
     )
@@ -279,7 +446,71 @@ def test_print_version_change(mocker, runner, capsys):
     assert outerr.out == "1.3.0"
     assert outerr.err == ""
 
-    mock_current_version.assert_called_once_with()
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", None)
+
+
+def test_print_version_change_prerelease(mocker, runner, capsys):
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value="minor"
+    )
+
+    print_version(prerelease=True)
+    outerr = capsys.readouterr()
+    assert outerr.out == "1.3.0-beta.1"
+    assert outerr.err == ""
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", None)
+
+
+def test_print_version_change_prerelease_no_patch(mocker, runner, capsys):
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value=None
+    )
+
+    print_version(prerelease=True, prerelease_patch=False)
+    outerr = capsys.readouterr()
+    assert outerr.out == ""
+    assert outerr.err == "No release will be made.\n"
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", None)
+
+
+def test_print_version_change_prerelease_bump(mocker, runner, capsys):
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value="minor"
+    )
+
+    print_version(prerelease=True)
+    outerr = capsys.readouterr()
+    assert outerr.out == "1.3.0-beta.1"
+    assert outerr.err == ""
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", None)
 
 
@@ -287,6 +518,9 @@ def test_print_version_force_major(mocker, runner, capsys):
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
     mock_evaluate_bump = mocker.patch(
         "semantic_release.cli.evaluate_version_bump", return_value="major"
     )
@@ -296,7 +530,29 @@ def test_print_version_force_major(mocker, runner, capsys):
     assert outerr.out == "2.0.0"
     assert outerr.err == ""
 
-    mock_current_version.assert_called_once_with()
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", "major")
+
+
+def test_print_version_force_major_prerelease(mocker, runner, capsys):
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+    mock_evaluate_bump = mocker.patch(
+        "semantic_release.cli.evaluate_version_bump", return_value="major"
+    )
+
+    print_version(force_level="major", prerelease=True)
+    outerr = capsys.readouterr()
+    assert outerr.out == "2.0.0-beta.1"
+    assert outerr.err == ""
+
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", "major")
 
 
@@ -313,12 +569,16 @@ def test_version_no_change(mocker, runner):
     mock_current_version = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="1.2.3"
     )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
 
     version()
 
-    mock_current_version.assert_called_once_with()
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
     mock_evaluate_bump.assert_called_once_with("1.2.3", None)
-    mock_new_version.assert_called_once_with("1.2.3", None)
+    mock_new_version.assert_called_once_with("1.2.3", "1.2.3", None, False, True)
     assert not mock_set_new_version.called
     assert not mock_commit_new_version.called
     assert not mock_tag_new_version.called
@@ -383,6 +643,29 @@ def test_version_by_tag_check_build_status_succeeds(mocker):
     assert mock_tag_new_version.called
 
 
+def test_version_by_tag_only_check_build_status_succeeds(mocker):
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(
+            version_source="tag_only",
+            commit_version_number=False,
+            check_build_status=True,
+        ),
+    )
+    mock_check_build_status = mocker.patch(
+        "semantic_release.cli.check_build_status", return_value=True
+    )
+    mock_set_new_version = mocker.patch("semantic_release.cli.set_new_version")
+    mock_tag_new_version = mocker.patch("semantic_release.cli.tag_new_version")
+    mocker.patch("semantic_release.cli.evaluate_version_bump", lambda *x: "major")
+
+    version()
+
+    assert mock_check_build_status.called
+    assert not mock_set_new_version.called
+    assert mock_tag_new_version.called
+
+
 def test_version_check_build_status_not_called_if_disabled(mocker):
     mock_check_build_status = mocker.patch("semantic_release.cli.check_build_status")
     mocker.patch("semantic_release.cli.config.get", lambda *x, **y: False)
@@ -407,8 +690,11 @@ def test_version_retry_and_giterror(mocker):
 
 
 def test_version_retry(mocker):
-    mock_get_current = mocker.patch(
-        "semantic_release.cli.get_current_version", return_value="current"
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
     )
     mock_evaluate_bump = mocker.patch(
         "semantic_release.cli.evaluate_version_bump", return_value="patch"
@@ -421,15 +707,105 @@ def test_version_retry(mocker):
     result = version(noop=False, retry=True, force_level=False)
 
     assert result
-    mock_get_current.assert_called_once_with()
-    mock_evaluate_bump.assert_called_once_with("current", False)
-    mock_get_new.assert_called_once_with("current", "patch")
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate_bump.assert_called_once_with("1.2.3", False)
+    mock_get_new.assert_called_once_with("1.2.3", "1.2.3", "patch", False, True)
+
+
+def test_publish_should_not_run_pre_commit_by_default(mocker):
+    mocker.patch("semantic_release.cli.checkout")
+    mocker.patch("semantic_release.cli.ci_checks.check")
+    mocker.patch.object(ArtifactRepo, "upload")
+    mocker.patch("semantic_release.cli.upload_to_release")
+    mocker.patch("semantic_release.cli.post_changelog", lambda *x: True)
+    mocker.patch("semantic_release.cli.push_new_version", return_value=True)
+    mocker.patch("semantic_release.cli.should_bump_version", return_value=True)
+    mocker.patch("semantic_release.cli.markdown_changelog", lambda *x, **y: "CHANGES")
+    mocker.patch("semantic_release.cli.update_changelog_file")
+    mocker.patch("semantic_release.cli.bump_version")
+    mocker.patch("semantic_release.cli.get_new_version", lambda *x: "2.0.0")
+    mocker.patch("semantic_release.cli.check_token", lambda: True)
+    run_pre_commit = mocker.patch("semantic_release.cli.run_pre_commit")
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(
+            remove_dist=False,
+            upload_to_pypi=False,
+            upload_to_release=False,
+        ),
+    )
+    mocker.patch("semantic_release.cli.update_changelog_file", lambda *x, **y: None)
+
+    publish()
+
+    assert not run_pre_commit.called
+
+
+def test_publish_should_not_run_pre_commit_with_empty_command(mocker):
+    mocker.patch("semantic_release.cli.checkout")
+    mocker.patch("semantic_release.cli.ci_checks.check")
+    mocker.patch.object(ArtifactRepo, "upload")
+    mocker.patch("semantic_release.cli.upload_to_release")
+    mocker.patch("semantic_release.cli.post_changelog", lambda *x: True)
+    mocker.patch("semantic_release.cli.push_new_version", return_value=True)
+    mocker.patch("semantic_release.cli.should_bump_version", return_value=True)
+    mocker.patch("semantic_release.cli.markdown_changelog", lambda *x, **y: "CHANGES")
+    mocker.patch("semantic_release.cli.update_changelog_file")
+    mocker.patch("semantic_release.cli.bump_version")
+    mocker.patch("semantic_release.cli.get_new_version", lambda *x: "2.0.0")
+    mocker.patch("semantic_release.cli.check_token", lambda: True)
+    run_pre_commit = mocker.patch("semantic_release.cli.run_pre_commit")
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(
+            remove_dist=False,
+            upload_to_pypi=False,
+            upload_to_release=False,
+            pre_commit_command="",
+        ),
+    )
+    mocker.patch("semantic_release.cli.update_changelog_file", lambda *x, **y: None)
+
+    publish()
+
+    assert not run_pre_commit.called
+
+
+def test_publish_should_run_pre_commit_if_provided(mocker):
+    mocker.patch("semantic_release.cli.checkout")
+    mocker.patch("semantic_release.cli.ci_checks.check")
+    mocker.patch.object(ArtifactRepo, "upload")
+    mocker.patch("semantic_release.cli.upload_to_release")
+    mocker.patch("semantic_release.cli.post_changelog", lambda *x: True)
+    mocker.patch("semantic_release.cli.push_new_version", return_value=True)
+    mocker.patch("semantic_release.cli.should_bump_version", return_value=True)
+    mocker.patch("semantic_release.cli.markdown_changelog", lambda *x, **y: "CHANGES")
+    mocker.patch("semantic_release.cli.update_changelog_file")
+    mocker.patch("semantic_release.cli.bump_version")
+    mocker.patch("semantic_release.cli.get_new_version", lambda *x: "2.0.0")
+    mocker.patch("semantic_release.cli.check_token", lambda: True)
+    run_pre_commit = mocker.patch("semantic_release.cli.run_pre_commit")
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(
+            remove_dist=False,
+            upload_to_pypi=False,
+            upload_to_release=False,
+            pre_commit_command='echo "Hello, world."',
+        ),
+    )
+    mocker.patch("semantic_release.cli.update_changelog_file", lambda *x, **y: None)
+
+    publish()
+
+    assert run_pre_commit.called
 
 
 def test_publish_should_not_upload_to_pypi_if_option_is_false(mocker):
     mocker.patch("semantic_release.cli.checkout")
     mocker.patch("semantic_release.cli.ci_checks.check")
-    mock_upload_pypi = mocker.patch("semantic_release.cli.upload_to_pypi")
+    mock_repository = mocker.patch.object(ArtifactRepo, "upload")
     mock_upload_release = mocker.patch("semantic_release.cli.upload_to_release")
     mocker.patch("semantic_release.cli.post_changelog", lambda *x: True)
     mocker.patch("semantic_release.cli.push_new_version", return_value=True)
@@ -451,7 +827,36 @@ def test_publish_should_not_upload_to_pypi_if_option_is_false(mocker):
 
     publish()
 
-    assert not mock_upload_pypi.called
+    assert not mock_repository.called
+    assert not mock_upload_release.called
+
+
+def test_publish_should_not_upload_to_repository_if_option_is_false(mocker):
+    mocker.patch("semantic_release.cli.checkout")
+    mocker.patch("semantic_release.cli.ci_checks.check")
+    mock_repository = mocker.patch.object(ArtifactRepo, "upload")
+    mock_upload_release = mocker.patch("semantic_release.cli.upload_to_release")
+    mocker.patch("semantic_release.cli.post_changelog", lambda *x: True)
+    mocker.patch("semantic_release.cli.push_new_version", return_value=True)
+    mocker.patch("semantic_release.cli.should_bump_version", return_value=False)
+    mocker.patch("semantic_release.cli.markdown_changelog", lambda *x, **y: "CHANGES")
+    mocker.patch("semantic_release.cli.update_changelog_file")
+    mocker.patch("semantic_release.cli.bump_version")
+    mocker.patch("semantic_release.cli.get_new_version", lambda *x: "2.0.0")
+    mocker.patch("semantic_release.cli.check_token", lambda: True)
+    mocker.patch(
+        "semantic_release.cli.config.get",
+        wrapped_config_get(
+            remove_dist=False,
+            upload_to_repository=False,
+            upload_to_release=False,
+        ),
+    )
+    mocker.patch("semantic_release.cli.update_changelog_file", lambda *x, **y: None)
+
+    publish()
+
+    assert not mock_repository.called
     assert not mock_upload_release.called
 
 
@@ -461,7 +866,7 @@ def test_publish_should_do_nothing_when_not_should_bump_version(mocker):
     mocker.patch("semantic_release.cli.evaluate_version_bump", lambda *x: "feature")
     mocker.patch("semantic_release.cli.generate_changelog")
     mock_log = mocker.patch("semantic_release.cli.post_changelog")
-    mock_upload_pypi = mocker.patch("semantic_release.cli.upload_to_pypi")
+    mock_repository = mocker.patch.object(ArtifactRepo, "upload")
     mock_upload_release = mocker.patch("semantic_release.cli.upload_to_release")
     mock_push = mocker.patch("semantic_release.cli.push_new_version")
     mock_ci_check = mocker.patch("semantic_release.ci_checks.check")
@@ -473,7 +878,7 @@ def test_publish_should_do_nothing_when_not_should_bump_version(mocker):
 
     assert mock_should_bump_version.called
     assert not mock_push.called
-    assert not mock_upload_pypi.called
+    assert not mock_repository.called
     assert not mock_upload_release.called
     assert not mock_log.called
     assert mock_ci_check.called
@@ -487,7 +892,14 @@ def test_publish_should_call_functions(mocker):
     )
     mock_log = mocker.patch("semantic_release.cli.post_changelog")
     mock_ci_check = mocker.patch("semantic_release.ci_checks.check")
-    mock_pypi = mocker.patch("semantic_release.cli.upload_to_pypi")
+    mocker.patch.dict(
+        "os.environ",
+        {
+            "REPOSITORY_USERNAME": "repo-username",
+            "REPOSITORY_PASSWORD": "repo-password",
+        },
+    )
+    mock_repository = mocker.patch.object(ArtifactRepo, "upload")
     mock_release = mocker.patch("semantic_release.cli.upload_to_release")
     mock_build_dists = mocker.patch("semantic_release.cli.build_dists")
     mock_remove_dists = mocker.patch("semantic_release.cli.remove_dists")
@@ -509,11 +921,11 @@ def test_publish_should_call_functions(mocker):
     assert mock_push.called
     assert mock_remove_dists.called
     assert mock_build_dists.called
-    assert mock_pypi.called
+    assert mock_repository.called
     assert mock_release.called
     assert mock_should_bump_version.called
     mock_log.assert_called_once_with(
-        u"relekang", "python-semantic-release", "2.0.0", "CHANGES"
+        "relekang", "python-semantic-release", "2.0.0", "CHANGES"
     )
     mock_checkout.assert_called_once_with("master")
 
@@ -526,7 +938,14 @@ def test_publish_should_skip_build_when_command_is_empty(mocker):
     )
     mock_log = mocker.patch("semantic_release.cli.post_changelog")
     mock_ci_check = mocker.patch("semantic_release.ci_checks.check")
-    mock_pypi = mocker.patch("semantic_release.cli.upload_to_pypi")
+    mocker.patch.dict(
+        "os.environ",
+        {
+            "REPOSITORY_USERNAME": "repo-username",
+            "REPOSITORY_PASSWORD": "repo-password",
+        },
+    )
+    mock_repository = mocker.patch.object(ArtifactRepo, "upload")
     mock_release = mocker.patch("semantic_release.cli.upload_to_release")
     mock_build_dists = mocker.patch("semantic_release.cli.build_dists")
     mock_remove_dists = mocker.patch("semantic_release.cli.remove_dists")
@@ -555,59 +974,11 @@ def test_publish_should_skip_build_when_command_is_empty(mocker):
     assert mock_push.called
     assert not mock_remove_dists.called
     assert not mock_build_dists.called
-    assert mock_pypi.called
+    assert mock_repository.called
     assert mock_release.called
     assert mock_should_bump_version.called
     mock_log.assert_called_once_with(
-        u"relekang", "python-semantic-release", "2.0.0", "CHANGES"
-    )
-    mock_checkout.assert_called_once_with("master")
-
-
-def test_publish_should_call_functions_with_custom_pypi_glob_patterns(mocker):
-    mock_push = mocker.patch("semantic_release.cli.push_new_version")
-    mock_checkout = mocker.patch("semantic_release.cli.checkout")
-    mock_should_bump_version = mocker.patch(
-        "semantic_release.cli.should_bump_version", return_value=True
-    )
-    mock_log = mocker.patch("semantic_release.cli.post_changelog")
-    mock_ci_check = mocker.patch("semantic_release.ci_checks.check")
-    mock_pypi = mocker.patch("semantic_release.cli.upload_to_pypi")
-    mock_release = mocker.patch("semantic_release.cli.upload_to_release")
-    mock_build_dists = mocker.patch("semantic_release.cli.build_dists")
-    mock_remove_dists = mocker.patch("semantic_release.cli.remove_dists")
-    mocker.patch(
-        "semantic_release.cli.get_repository_owner_and_name",
-        return_value=("relekang", "python-semantic-release"),
-    )
-    mocker.patch("semantic_release.cli.evaluate_version_bump", lambda *x: "feature")
-    mocker.patch("semantic_release.cli.generate_changelog")
-    mocker.patch("semantic_release.cli.markdown_changelog", lambda *x, **y: "CHANGES")
-    mocker.patch("semantic_release.cli.update_changelog_file")
-    mocker.patch("semantic_release.cli.bump_version")
-    mocker.patch("semantic_release.cli.get_new_version", lambda *x: "2.0.0")
-    mocker.patch("semantic_release.cli.check_token", lambda: True)
-
-    mocker.patch(
-        "semantic_release.cli.config.get",
-        wrapped_config_get(
-            upload_to_pypi_glob_patterns="*.tar.gz,*.whl",
-        ),
-    )
-
-    publish()
-
-    assert mock_ci_check.called
-    assert mock_push.called
-    assert mock_remove_dists.called
-    assert mock_build_dists.called
-    mock_pypi.assert_called_with(
-        path="dist", skip_existing=None, glob_patterns=["*.tar.gz", "*.whl"]
-    )
-    assert mock_release.called
-    assert mock_should_bump_version.called
-    mock_log.assert_called_once_with(
-        u"relekang", "python-semantic-release", "2.0.0", "CHANGES"
+        "relekang", "python-semantic-release", "2.0.0", "CHANGES"
     )
     mock_checkout.assert_called_once_with("master")
 
@@ -616,8 +987,11 @@ def test_publish_retry_version_fail(mocker):
     mock_get_current = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="current"
     )
-    mock_get_previous = mocker.patch(
-        "semantic_release.cli.get_previous_version", return_value="previous"
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+    get_previous_release_version = mocker.patch(
+        "semantic_release.cli.get_previous_release_version", return_value="previous"
     )
     mock_get_owner_name = mocker.patch(
         "semantic_release.cli.get_repository_owner_and_name",
@@ -632,13 +1006,19 @@ def test_publish_retry_version_fail(mocker):
 
     publish(noop=False, retry=True, force_level=False)
 
-    mock_get_current.assert_called_once_with()
-    mock_get_previous.assert_called_once_with("current")
+    mock_get_current.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    get_previous_release_version.assert_called_once_with("current")
     mock_get_owner_name.assert_called_once_with()
     mock_ci_check.assert_called()
     mock_checkout.assert_called_once_with("my_branch")
     mock_should_bump_version.assert_called_once_with(
-        current_version="previous", new_version="current", noop=False, retry=True
+        current_version="previous",
+        new_version="current",
+        current_release_version="1.2.3",
+        prerelease=False,
+        noop=False,
+        retry=True,
     )
 
 
@@ -646,8 +1026,11 @@ def test_publish_bad_token(mocker):
     mock_get_current = mocker.patch(
         "semantic_release.cli.get_current_version", return_value="current"
     )
-    mock_get_previous = mocker.patch(
-        "semantic_release.cli.get_previous_version", return_value="previous"
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
+    )
+    get_previous_release_version = mocker.patch(
+        "semantic_release.cli.get_previous_release_version", return_value="previous"
     )
     mock_get_owner_name = mocker.patch(
         "semantic_release.cli.get_repository_owner_and_name",
@@ -659,7 +1042,7 @@ def test_publish_bad_token(mocker):
         "semantic_release.cli.config.get",
         wrapped_config_get(
             branch="my_branch",
-            upload_to_pypi=False,
+            upload_to_repository=False,
             upload_to_release=False,
             remove_dist=False,
         ),
@@ -678,13 +1061,19 @@ def test_publish_bad_token(mocker):
 
     publish(noop=False, retry=True, force_level=False)
 
-    mock_get_current.assert_called_once_with()
-    mock_get_previous.assert_called_once_with("current")
+    mock_get_current.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    get_previous_release_version.assert_called_once_with("current")
     mock_get_owner_name.assert_called_once_with()
     mock_ci_check.assert_called()
     mock_checkout.assert_called_once_with("my_branch")
     mock_should_bump_version.assert_called_once_with(
-        current_version="previous", new_version="current", noop=False, retry=True
+        current_version="previous",
+        new_version="current",
+        current_release_version="1.2.3",
+        prerelease=False,
+        noop=False,
+        retry=True,
     )
     mock_get_token.assert_called()
     mock_get_domain.assert_called()
@@ -699,8 +1088,11 @@ def test_publish_bad_token(mocker):
 
 
 def test_publish_giterror_when_posting(mocker):
-    mock_get_current = mocker.patch(
-        "semantic_release.cli.get_current_version", return_value="current"
+    mock_current_version = mocker.patch(
+        "semantic_release.cli.get_current_version", return_value="1.2.3"
+    )
+    mock_current_release_version = mocker.patch(
+        "semantic_release.cli.get_current_release_version", return_value="1.2.3"
     )
     mock_evaluate = mocker.patch(
         "semantic_release.cli.evaluate_version_bump", return_value="patch"
@@ -718,7 +1110,7 @@ def test_publish_giterror_when_posting(mocker):
         "semantic_release.cli.config.get",
         wrapped_config_get(
             branch="my_branch",
-            upload_to_pypi=False,
+            upload_to_repository=False,
             upload_to_release=False,
             remove_dist=False,
         ),
@@ -752,14 +1144,20 @@ def test_publish_giterror_when_posting(mocker):
 
     publish(noop=False, retry=False, force_level=False)
 
-    mock_get_current.assert_called_once_with()
-    mock_evaluate.assert_called_once_with("current", False)
-    mock_get_new.assert_called_once_with("current", "patch")
+    mock_current_version.assert_called_once()
+    mock_current_release_version.assert_called_once()
+    mock_evaluate.assert_called_once_with("1.2.3", False)
+    mock_get_new.assert_called_once_with("1.2.3", "1.2.3", "patch", False, True)
     mock_get_owner_name.assert_called_once_with()
     mock_ci_check.assert_called()
     mock_checkout.assert_called_once_with("my_branch")
     mock_should_bump_version.assert_called_once_with(
-        current_version="current", new_version="new", noop=False, retry=False
+        current_version="1.2.3",
+        new_version="new",
+        current_release_version="1.2.3",
+        prerelease=False,
+        noop=False,
+        retry=False,
     )
     mock_update_changelog_file.assert_called_once_with("new", "super md changelog")
     mock_bump_version.assert_called_once_with("new", "patch")
@@ -773,14 +1171,14 @@ def test_publish_giterror_when_posting(mocker):
         domain="domain",
     )
     mock_check_token.assert_called_once_with()
-    mock_generate.assert_called_once_with("current")
+    mock_generate.assert_called_once_with("1.2.3")
     mock_markdown.assert_called_once_with(
         "owner",
         "name",
         "new",
         "super changelog",
         header=False,
-        previous_version="current",
+        previous_version="1.2.3",
     )
     mock_post.assert_called_once_with("owner", "name", "new", "super md changelog")
 
@@ -793,6 +1191,8 @@ def test_changelog_should_call_functions(mocker, runner):
         noop=False,
         post=False,
         force_level=None,
+        prerelease=False,
+        prerelease_patch=True,
         retry=False,
         unreleased=False,
         define=(),
@@ -800,7 +1200,9 @@ def test_changelog_should_call_functions(mocker, runner):
 
 
 def test_overload_by_cli(mocker, runner):
-    mock_open = mocker.patch("semantic_release.history.open", mock_version_file)
+    mock_read_text = mocker.patch(
+        "semantic_release.history.Path.read_text", mock_version_file
+    )
     runner.invoke(
         main,
         [
@@ -812,8 +1214,8 @@ def test_overload_by_cli(mocker, runner):
         ],
     )
 
-    mock_open.assert_called_once_with("my_version_path", "r")
-    mock_open.reset_mock()
+    mock_read_text.assert_called_once_with()
+    mock_read_text.reset_mock()
 
 
 def test_changelog_noop(mocker):
